@@ -7,6 +7,7 @@ Usage:
     codegraph-mcp status                            # Check server status
     codegraph-mcp serve --repo /path/to/project    # Start server in foreground
     codegraph-mcp index /path/to/project           # Index repository
+    codegraph-mcp watch /path/to/project           # Watch and auto-reindex
     codegraph-mcp query "find all functions"       # Execute query
     codegraph-mcp stats /path/to/project           # Show statistics
     codegraph-mcp --help
@@ -201,6 +202,31 @@ def create_parser() -> argparse.ArgumentParser:
         help="Minimum community size (default: 3)",
     )
 
+    # watch command - File watching for auto-reindex
+    watch_parser = subparsers.add_parser(
+        "watch",
+        help="Watch repository and auto-reindex on changes",
+    )
+    watch_parser.add_argument(
+        "path",
+        type=Path,
+        nargs="?",
+        default=Path.cwd(),
+        help="Repository path to watch (default: current directory)",
+    )
+    watch_parser.add_argument(
+        "--debounce",
+        type=float,
+        default=1.0,
+        help="Debounce delay in seconds (default: 1.0)",
+    )
+    watch_parser.add_argument(
+        "--community",
+        action="store_true",
+        default=False,
+        help="Run community detection after each reindex",
+    )
+
     return parser
 
 
@@ -208,10 +234,10 @@ def cmd_start(args: argparse.Namespace) -> int:
     """Handle start command - Start server in background."""
     pid_file = get_pid_file()
     log_file = get_log_file()
-    
+
     # Ensure directory exists
     pid_file.parent.mkdir(parents=True, exist_ok=True)
-    
+
     # Check if already running
     if pid_file.exists():
         try:
@@ -222,7 +248,7 @@ def cmd_start(args: argparse.Namespace) -> int:
         except (ProcessLookupError, ValueError):
             # Process not running, remove stale PID file
             pid_file.unlink()
-    
+
     # Build command
     cmd = [
         sys.executable, "-m", "codegraph_mcp",
@@ -231,19 +257,19 @@ def cmd_start(args: argparse.Namespace) -> int:
         "--transport", args.transport,
         "--port", str(args.port),
     ]
-    
+
     # Start server in background
-    with open(log_file, "w") as log:
+    with log_file.open("w") as log:
         process = subprocess.Popen(
             cmd,
             stdout=log,
             stderr=subprocess.STDOUT,
             start_new_session=True,
         )
-    
+
     # Write PID file
     pid_file.write_text(str(process.pid))
-    
+
     print("\u2705 Server started in background")
     print(f"   PID: {process.pid}")
     print(f"   Repository: {args.repo.resolve()}")
@@ -252,22 +278,22 @@ def cmd_start(args: argparse.Namespace) -> int:
         print(f"   URL: http://localhost:{args.port}")
     print(f"   Log: {log_file}")
     print("\nUse 'codegraph-mcp stop' to stop the server")
-    
+
     return 0
 
 
 def cmd_stop(args: argparse.Namespace) -> int:
     """Handle stop command - Stop background server."""
     pid_file = get_pid_file()
-    
+
     if not pid_file.exists():
         print("No server is running")
         return 1
-    
+
     try:
         pid = int(pid_file.read_text().strip())
         os.kill(pid, signal.SIGTERM)
-        
+
         # Wait for process to terminate
         import time
         for _ in range(10):
@@ -276,11 +302,11 @@ def cmd_stop(args: argparse.Namespace) -> int:
                 time.sleep(0.5)
             except ProcessLookupError:
                 break
-        
+
         pid_file.unlink()
         print(f"✅ Server stopped (PID: {pid})")
         return 0
-        
+
     except ProcessLookupError:
         pid_file.unlink()
         print("Server was not running (stale PID file removed)")
@@ -295,19 +321,19 @@ def cmd_status(args: argparse.Namespace) -> int:
     """Handle status command - Check server status."""
     pid_file = get_pid_file()
     log_file = get_log_file()
-    
+
     if not pid_file.exists():
         print("❌ Server is not running")
         return 1
-    
+
     try:
         pid = int(pid_file.read_text().strip())
         os.kill(pid, 0)  # Check if process exists
-        
+
         print("\u2705 Server is running")
         print(f"   PID: {pid}")
         print(f"   Log: {log_file}")
-        
+
         # Show last few log lines if available
         if log_file.exists():
             lines = log_file.read_text().strip().split("\n")
@@ -315,9 +341,9 @@ def cmd_status(args: argparse.Namespace) -> int:
                 print("\nRecent logs:")
                 for line in lines[-5:]:
                     print(f"   {line}")
-        
+
         return 0
-        
+
     except ProcessLookupError:
         pid_file.unlink()
         print("❌ Server is not running (stale PID file removed)")
@@ -353,10 +379,10 @@ def cmd_index(args: argparse.Namespace) -> int:
         try:
             from rich.console import Console
             from rich.progress import (
-                Progress,
-                TextColumn,
                 BarColumn,
+                Progress,
                 TaskProgressColumn,
+                TextColumn,
                 TimeElapsedColumn,
             )
             from rich.table import Table
@@ -416,8 +442,8 @@ def cmd_index(args: argparse.Namespace) -> int:
                 # Run community detection if enabled
                 community_result = None
                 if run_community and result.success:
-                    from codegraph_mcp.core.graph import GraphEngine
                     from codegraph_mcp.core.community import CommunityDetector
+                    from codegraph_mcp.core.graph import GraphEngine
 
                     engine = GraphEngine(args.path)
                     await engine.initialize()
@@ -507,8 +533,8 @@ def cmd_index(args: argparse.Namespace) -> int:
 
             # Run community detection if enabled
             if run_community and result.success:
-                from codegraph_mcp.core.graph import GraphEngine
                 from codegraph_mcp.core.community import CommunityDetector
+                from codegraph_mcp.core.graph import GraphEngine
 
                 engine = GraphEngine(args.path)
                 await engine.initialize()
@@ -606,8 +632,8 @@ def cmd_community(args: argparse.Namespace) -> int:
     """Handle community command."""
     import asyncio
 
-    from codegraph_mcp.core.graph import GraphEngine
     from codegraph_mcp.core.community import CommunityDetector
+    from codegraph_mcp.core.graph import GraphEngine
 
     async def _community() -> int:
         engine = GraphEngine(args.path)
@@ -649,6 +675,138 @@ def cmd_community(args: argparse.Namespace) -> int:
     return asyncio.run(_community())
 
 
+def cmd_watch(args: argparse.Namespace) -> int:
+    """Handle watch command - Watch for file changes and auto-reindex."""
+    import asyncio
+    import time
+
+    try:
+        from watchfiles import Change, awatch
+    except ImportError:
+        print("Error: watchfiles is required for watch command")
+        print("Install with: pip install watchfiles")
+        return 1
+
+    from codegraph_mcp.core.indexer import Indexer
+    from codegraph_mcp.core.parser import CodeParser
+
+    # Build set of supported extensions from parser
+    supported_extensions = set(CodeParser.LANGUAGE_EXTENSIONS.keys())
+
+    async def _watch() -> int:
+        indexer = Indexer()
+        repo_path = args.path.resolve()
+
+        print(f"\n[Watch Mode] Watching: {repo_path}")
+        print(f"[Watch Mode] Debounce: {args.debounce}s")
+        print(f"[Watch Mode] Community detection: {args.community}")
+        print("[Watch Mode] Press Ctrl+C to stop\n")
+
+        # Initial index
+        print("[Watch Mode] Running initial index...")
+        result = await indexer.index_repository(repo_path, incremental=False)
+        print(
+            f"[Watch Mode] Initial: {result.entities_count} entities, "
+            f"{result.relations_count} relations"
+        )
+
+        # Track pending changes for debouncing
+        pending_files: set[Path] = set()
+        last_change_time = 0.0
+
+        async def process_changes() -> None:
+            """Process accumulated changes after debounce."""
+            nonlocal pending_files, last_change_time
+
+            if not pending_files:
+                return
+
+            # Filter to supported files
+            files_to_index = [
+                f for f in pending_files
+                if f.suffix in supported_extensions and f.exists()
+            ]
+
+            if not files_to_index:
+                pending_files.clear()
+                return
+
+            print(f"\n[Watch Mode] Reindexing {len(files_to_index)} files...")
+            start = time.time()
+
+            result = await indexer.index_repository(
+                repo_path,
+                incremental=True,
+            )
+
+            elapsed = time.time() - start
+            print(
+                f"[Watch Mode] Done: {result.entities_count} entities, "
+                f"{result.relations_count} relations ({elapsed:.2f}s)"
+            )
+
+            # Run community detection if enabled
+            if args.community and result.success:
+                from codegraph_mcp.core.community import CommunityDetector
+                from codegraph_mcp.core.graph import GraphEngine
+
+                engine = GraphEngine(repo_path)
+                await engine.initialize()
+                try:
+                    detector = CommunityDetector()
+                    if result.changed_entity_ids:
+                        comm_result = await detector.update_incremental(
+                            engine, result.changed_entity_ids
+                        )
+                        print(
+                            f"[Watch Mode] Communities updated: "
+                            f"{len(comm_result.communities)}"
+                        )
+                finally:
+                    await engine.close()
+
+            pending_files.clear()
+
+        try:
+            async for changes in awatch(
+                repo_path,
+                debounce=int(args.debounce * 1000),
+                recursive=True,
+            ):
+                for change_type, file_path in changes:
+                    path = Path(file_path)
+
+                    # Skip non-code files and hidden files
+                    if path.suffix not in supported_extensions:
+                        continue
+                    if any(part.startswith('.') for part in path.parts):
+                        continue
+
+                    # Log change
+                    change_name = {
+                        Change.added: "Added",
+                        Change.modified: "Modified",
+                        Change.deleted: "Deleted",
+                    }.get(change_type, "Changed")
+
+                    rel_path = path.relative_to(repo_path)
+                    print(f"[Watch Mode] {change_name}: {rel_path}")
+
+                    if change_type != Change.deleted:
+                        pending_files.add(path)
+
+                    last_change_time = time.time()
+
+                # Process after debounce
+                await process_changes()
+
+        except KeyboardInterrupt:
+            print("\n[Watch Mode] Stopped")
+            return 0
+
+    return asyncio.run(_watch())
+
+
 def main() -> int:
     """Main entry point."""
     parser = create_parser()
@@ -664,6 +822,7 @@ def main() -> int:
         "status": cmd_status,
         "serve": cmd_serve,
         "index": cmd_index,
+        "watch": cmd_watch,
         "query": cmd_query,
         "stats": cmd_stats,
         "community": cmd_community,
@@ -676,7 +835,7 @@ def main() -> int:
         except Exception as e:
             print(f"Error: {e}", file=sys.stderr)
             return 1
-    
+
     parser.print_help()
     return 0
 
