@@ -28,7 +28,7 @@ from codegraph_mcp.languages.config import (
 class CSharpExtractor(BaseExtractor):
     """
     C#-specific entity and relation extractor.
-    
+
     Extracts:
     - Classes (class)
     - Structs (struct)
@@ -38,10 +38,10 @@ class CSharpExtractor(BaseExtractor):
     - Namespaces (namespace)
     - Using statements (imports)
     - Enums (enum)
-    
+
     Requirements: REQ-AST-006
     """
-    
+
     config = LanguageConfig(
         name="csharp",
         extensions=[".cs"],
@@ -51,7 +51,7 @@ class CSharpExtractor(BaseExtractor):
         import_nodes=["using_directive"],
         interface_nodes=["interface_declaration"],
     )
-    
+
     def extract(
         self,
         tree: Any,
@@ -61,12 +61,12 @@ class CSharpExtractor(BaseExtractor):
         """Extract entities and relations from C# AST."""
         entities: list[Entity] = []
         relations: list[Relation] = []
-        
+
         # Extract namespace for module entity
         namespace = self._extract_namespace(tree.root_node, source_code)
         module_name = namespace or file_path.stem
         module_id = self._generate_entity_id(file_path, module_name, 1)
-        
+
         entities.append(Entity(
             id=module_id,
             type=EntityType.MODULE,
@@ -80,7 +80,7 @@ class CSharpExtractor(BaseExtractor):
                 end_column=0,
             ),
         ))
-        
+
         # Walk the tree
         self._walk_tree(
             tree.root_node,
@@ -91,9 +91,9 @@ class CSharpExtractor(BaseExtractor):
             module_id,
             namespace,
         )
-        
+
         return ParseResult(entities=entities, relations=relations)
-    
+
     def _extract_namespace(self, root_node: Any, source_code: str) -> str | None:
         """Extract namespace from AST."""
         for child in root_node.children:
@@ -102,7 +102,7 @@ class CSharpExtractor(BaseExtractor):
                     if ns_child.type in ("qualified_name", "identifier"):
                         return self._get_node_text(ns_child, source_code)
         return None
-    
+
     def _walk_tree(
         self,
         node: Any,
@@ -114,7 +114,7 @@ class CSharpExtractor(BaseExtractor):
         namespace: str | None,
     ) -> None:
         """Recursively walk the AST tree."""
-        
+
         if node.type == "class_declaration":
             entity = self._extract_class(node, file_path, source_code, namespace)
             if entity:
@@ -128,7 +128,7 @@ class CSharpExtractor(BaseExtractor):
                 self._extract_class_members(
                     node, file_path, source_code, entities, relations, entity.id, namespace
                 )
-        
+
         elif node.type == "struct_declaration":
             entity = self._extract_struct(node, file_path, source_code, namespace)
             if entity:
@@ -141,7 +141,7 @@ class CSharpExtractor(BaseExtractor):
                 self._extract_class_members(
                     node, file_path, source_code, entities, relations, entity.id, namespace
                 )
-        
+
         elif node.type == "interface_declaration":
             entity = self._extract_interface(node, file_path, source_code, namespace)
             if entity:
@@ -152,7 +152,7 @@ class CSharpExtractor(BaseExtractor):
                     type=RelationType.CONTAINS,
                 ))
                 self._extract_base_types(node, source_code, entity.id, relations, is_interface=True)
-        
+
         elif node.type == "enum_declaration":
             entity = self._extract_enum(node, file_path, source_code, namespace)
             if entity:
@@ -162,10 +162,10 @@ class CSharpExtractor(BaseExtractor):
                     target_id=entity.id,
                     type=RelationType.CONTAINS,
                 ))
-        
+
         elif node.type == "using_directive":
             self._extract_using(node, source_code, parent_id, relations)
-        
+
         # Recurse (but not into class/struct bodies)
         if node.type not in ("class_declaration", "struct_declaration", "interface_declaration"):
             for child in node.children:
@@ -173,7 +173,7 @@ class CSharpExtractor(BaseExtractor):
                     child, file_path, source_code,
                     entities, relations, parent_id, namespace,
                 )
-    
+
     def _extract_class(
         self,
         node: Any,
@@ -187,17 +187,14 @@ class CSharpExtractor(BaseExtractor):
             if child.type == "identifier":
                 name = self._get_node_text(child, source_code)
                 break
-        
+
         if not name:
             return None
-        
-        if namespace:
-            qualified_name = f"{file_path}::{namespace}.{name}"
-        else:
-            qualified_name = f"{file_path}::{name}"
-        
+
+        qualified_name = f"{file_path}::{namespace}.{name}" if namespace else f"{file_path}::{name}"
+
         docstring = self._extract_doc_comment(node, source_code)
-        
+
         return Entity(
             id=self._generate_entity_id(file_path, name, node.start_point[0] + 1),
             type=EntityType.CLASS,
@@ -213,7 +210,7 @@ class CSharpExtractor(BaseExtractor):
             docstring=docstring,
             source_code=self._get_node_text(node, source_code),
         )
-    
+
     def _extract_struct(
         self,
         node: Any,
@@ -227,17 +224,14 @@ class CSharpExtractor(BaseExtractor):
             if child.type == "identifier":
                 name = self._get_node_text(child, source_code)
                 break
-        
+
         if not name:
             return None
-        
-        if namespace:
-            qualified_name = f"{file_path}::{namespace}.{name}"
-        else:
-            qualified_name = f"{file_path}::{name}"
-        
+
+        qualified_name = f"{file_path}::{namespace}.{name}" if namespace else f"{file_path}::{name}"
+
         docstring = self._extract_doc_comment(node, source_code)
-        
+
         return Entity(
             id=self._generate_entity_id(file_path, name, node.start_point[0] + 1),
             type=EntityType.STRUCT,
@@ -253,7 +247,7 @@ class CSharpExtractor(BaseExtractor):
             docstring=docstring,
             source_code=self._get_node_text(node, source_code),
         )
-    
+
     def _extract_interface(
         self,
         node: Any,
@@ -267,17 +261,14 @@ class CSharpExtractor(BaseExtractor):
             if child.type == "identifier":
                 name = self._get_node_text(child, source_code)
                 break
-        
+
         if not name:
             return None
-        
-        if namespace:
-            qualified_name = f"{file_path}::{namespace}.{name}"
-        else:
-            qualified_name = f"{file_path}::{name}"
-        
+
+        qualified_name = f"{file_path}::{namespace}.{name}" if namespace else f"{file_path}::{name}"
+
         docstring = self._extract_doc_comment(node, source_code)
-        
+
         return Entity(
             id=self._generate_entity_id(file_path, name, node.start_point[0] + 1),
             type=EntityType.INTERFACE,
@@ -293,7 +284,7 @@ class CSharpExtractor(BaseExtractor):
             docstring=docstring,
             source_code=self._get_node_text(node, source_code),
         )
-    
+
     def _extract_enum(
         self,
         node: Any,
@@ -307,17 +298,14 @@ class CSharpExtractor(BaseExtractor):
             if child.type == "identifier":
                 name = self._get_node_text(child, source_code)
                 break
-        
+
         if not name:
             return None
-        
-        if namespace:
-            qualified_name = f"{file_path}::{namespace}.{name}"
-        else:
-            qualified_name = f"{file_path}::{name}"
-        
+
+        qualified_name = f"{file_path}::{namespace}.{name}" if namespace else f"{file_path}::{name}"
+
         docstring = self._extract_doc_comment(node, source_code)
-        
+
         return Entity(
             id=self._generate_entity_id(file_path, name, node.start_point[0] + 1),
             type=EntityType.ENUM,
@@ -333,7 +321,7 @@ class CSharpExtractor(BaseExtractor):
             docstring=docstring,
             source_code=self._get_node_text(node, source_code),
         )
-    
+
     def _extract_class_members(
         self,
         node: Any,
@@ -368,7 +356,7 @@ class CSharpExtractor(BaseExtractor):
                                 type=RelationType.CONTAINS,
                             ))
                             self._extract_calls(member, file_path, source_code, entity.id, relations)
-    
+
     def _extract_method(
         self,
         node: Any,
@@ -382,14 +370,14 @@ class CSharpExtractor(BaseExtractor):
             if child.type == "identifier":
                 name = self._get_node_text(child, source_code)
                 break
-        
+
         if not name:
             return None
-        
+
         qualified_name = f"{file_path}::{name}"
         signature = self._extract_method_signature(node, name, source_code)
         docstring = self._extract_doc_comment(node, source_code)
-        
+
         return Entity(
             id=self._generate_entity_id(file_path, name, node.start_point[0] + 1),
             type=EntityType.METHOD,
@@ -406,7 +394,7 @@ class CSharpExtractor(BaseExtractor):
             docstring=docstring,
             source_code=self._get_node_text(node, source_code),
         )
-    
+
     def _extract_constructor(
         self,
         node: Any,
@@ -420,13 +408,13 @@ class CSharpExtractor(BaseExtractor):
             if child.type == "identifier":
                 name = self._get_node_text(child, source_code)
                 break
-        
+
         if not name:
             return None
-        
+
         qualified_name = f"{file_path}::{name}"
         signature = self._extract_method_signature(node, name, source_code)
-        
+
         return Entity(
             id=self._generate_entity_id(file_path, name, node.start_point[0] + 1),
             type=EntityType.METHOD,
@@ -442,7 +430,7 @@ class CSharpExtractor(BaseExtractor):
             signature=signature,
             source_code=self._get_node_text(node, source_code),
         )
-    
+
     def _extract_base_types(
         self,
         node: Any,
@@ -457,16 +445,14 @@ class CSharpExtractor(BaseExtractor):
                 for base_child in child.children:
                     if base_child.type in ("identifier", "generic_name", "qualified_name"):
                         base_name = self._get_node_text(base_child, source_code)
-                        # In C#, first base can be class, rest are interfaces
-                        # For simplicity, we'll mark all as INHERITS for interfaces
-                        # and first as INHERITS, rest as IMPLEMENTS for classes
-                        rel_type = RelationType.INHERITS if is_interface else RelationType.INHERITS
+                        # In C#, base types include both inheritance and interface implementation
+                        # For simplicity, we mark all as INHERITS
                         relations.append(Relation(
                             source_id=entity_id,
                             target_id=f"unresolved::{base_name}",
-                            type=rel_type,
+                            type=RelationType.INHERITS,
                         ))
-    
+
     def _extract_using(
         self,
         node: Any,
@@ -484,7 +470,7 @@ class CSharpExtractor(BaseExtractor):
                     type=RelationType.IMPORTS,
                 ))
                 break
-    
+
     def _extract_calls(
         self,
         node: Any,
@@ -515,10 +501,10 @@ class CSharpExtractor(BaseExtractor):
                         type=RelationType.CALLS,
                     ))
                     break
-        
+
         for child in node.children:
             self._extract_calls(child, file_path, source_code, caller_id, relations)
-    
+
     def _extract_method_signature(
         self,
         node: Any,
@@ -529,7 +515,7 @@ class CSharpExtractor(BaseExtractor):
         params = ""
         return_type = ""
         modifiers = []
-        
+
         for child in node.children:
             if child.type == "parameter_list":
                 params = self._get_node_text(child, source_code)
@@ -538,12 +524,12 @@ class CSharpExtractor(BaseExtractor):
                     return_type = self._get_node_text(child, source_code)
             elif child.type == "modifier":
                 modifiers.append(self._get_node_text(child, source_code))
-        
+
         mod_str = " ".join(modifiers)
         if mod_str:
             return f"{mod_str} {return_type} {name}{params}"
         return f"{return_type} {name}{params}"
-    
+
     def _extract_doc_comment(self, node: Any, source_code: str) -> str | None:
         """Extract XML doc comment."""
         return None
